@@ -20,9 +20,15 @@ done
 #
 cd ${TOPLEVEL}
 mkdir -p mac/build
-eval $(gcc -E -dM src/Audacity.h | awk '/#define *AUDACITY_(VERSION|RELEASE|REVISION|MODLEVEL) /{print $2 "=" $3}')
+eval $(g++ -E -dM src/Audacity.h | awk '/#define *AUDACITY_(VERSION|RELEASE|REVISION|MODLEVEL) /{print $2 "=" $3}')
+case $CONFIGURATION in
+Debug|Debug64)
+    AUDACITY_EXECUTABLE=Audacity;;
+*)
+    AUDACITY_EXECUTABLE=Audacity.sh;;
+esac
 cat >mac/build/Info.plist.h <<EOF
-#define AUDACITY_EXECUTABLE Audacity
+#define AUDACITY_EXECUTABLE ${AUDACITY_EXECUTABLE}
 #define AUDACITY_VERSION ${AUDACITY_VERSION}
 #define AUDACITY_RELEASE ${AUDACITY_RELEASE}
 #define AUDACITY_REVISION ${AUDACITY_REVISION}
